.. _docs:

Globus Provision Documentation
==============================

.. ifconfig:: website == "yes"

   .. note::
   	  The documentation is also available as:
   	  
   	  .. hlist::
   	     :columns: 2
   	     
   	     * `Single HTML <singlehtml/docs.html>`_
   	     * :docs-zip:`Single HTML (downloadable .zip) <singlehtml>`
   	     * :docs-tar:`Single HTML (downloadable .tar.gz) <singlehtml>`
   	     * :docs-zip:`Multiple HTML (downloadable .zip) <html>`
   	     * :docs-tar:`Multiple HTML (downloadable .tar.gz) <html>`
   	     * :docs-pdf:`PDF <pdf>`
   	  


.. toctree::
   :maxdepth: 2

   intro.rst
   quickstart.rst
   install.rst
   ec2.rst
   instance_operations.rst
   go.rst
   topology.rst
   developer.rst
   guides.rst
   config_ref_top.rst
   stopology_ref_top.rst
   topology_ref_top.rst
   cli_ref_top.rst
   recipe_ref_top.rst
   changelog.rst

.. Indices and tables
   ==================
	
   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`

